@@ -72,8 +72,14 @@ class Image(object):
         raise NotImplementedError()
 
     def __repr__(self):
-        return "" % (self.__class__.__module__, self.__class__.__name__,
-                        self.mode, self.size[0], self.size[1], id(self))
+        return "%(module)s.%(classname)s(%(id)s) " \
+                "<%(width)sx%(height)s, mode=%(mode)s>" % dict(
+                    module=self.__class__.__module__,
+                    classname=self.__class__.__name__,
+                    mode=self.mode,
+                    width=self.size[0],
+                    height=self.size[1],
+                    id=id(self))
 
     def copy(self):
         """
@@ -496,10 +502,6 @@ class Image(object):
         configure the file reader (where applicable), and finally resizes the
         image.
 
-        Note that the bilinear and bicubic filters in the current version of
-        PIL are not well-suited for thumbnail generation. You should use
-        ANTIALIAS unless speed is much more important than quality.
-
         Also note that this function modifies the Image object in place. If
         you need to use the full resolution image as well, apply this method
         to a :meth:`Image.copy` of the original image.
